/*****************************************************************************
 *****************************************************************************
 Copyright (c) 1999 - 2000, Intel Corporation 

 All rights reserved.

 Redistribution and use in source and binary forms, with or without 
 modification, are permitted provided that the following conditions are met:

 1. Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.

 3. Neither the name of Intel Corporation nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED. IN NO EVENT SHALL CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 

 *****************************************************************************
 ****************************************************************************/

 /***************************************************************************
 **                                                                        **
 ** INTEL CORPORATION                                                      **
 **                                                                        **
 ** This software is supplied under the terms of the license included      **
 ** above.  All use of this software must be in accordance with the terms  **
 ** of that license.                                                       **
 **                                                                        **
 **  THIS FILE IS INCLUDED BY ians_core.o. HENCE, IT SHOULD NOT BE         **
 **  MODIFIED!                                                             **
 **                                                                        **
 **  Module Name:                                                          **
 **    ians_kernel.h                                                       **
 **                                                                        **
 **  Abstract:                                                             **
 **    This module contains all the functions needed for the interface of  **
 **    the iANS module with the kernel.                                    **
 **                                                                        **
 **                                                                        **
 **  Environment:                                                          **
 **    Kernel Mode (linux 2.2.x, 2.4.x)                                    **
 **                                                                        **
 ***************************************************************************/


#ifndef _IANS_KERNEL_H_
#define _IANS_KERNEL_H_

#include "incg_types.h"

typedef enum _IANS_FLOW_MODE {
		RECEIVE,
		TRANSMIT
} IANS_FLOW_MODE;

int iansInitMemberDev(const char *baseName, device_t **ansDev);

BOOLEAN iansBaseDevIsOpen(device_t *ansDev);

int iansInitVadapterDev(const char *name, device_t **ansVadapterDev);

int iansRegisterDev(device_t *ansDev);

void iansUnregisterDev(device_t *ansDev,BOOLEAN close);

void iansVadapterSetMac(device_t *ansDev);

int iansIfReceive(device_t *ansDev, message_t *msg);

void iansIfStop(device_t *ansDev);

void iansIfWake(device_t *ansDev); 

void  iansConvertProbeMessageToAnsMessage(pOsMessage_t osMsg, message_t *ansMsg, IANS_FLOW_MODE flow ); 

int iansGetSizeofStats(void);

void iansSubStats(pstats_t destStats, pstats_t srcStats);

void iansAddStats(pstats_t destStats, pstats_t srcStats);

void iansResetStats(pstats_t stats); 

void iansSetStats(pstats_t stats, ULONG rx_packets, ULONG tx_packets);

unsigned long iansGetDeviceBaseAddr(device_t *ansDev);

void iansLock(void);

void iansUnlock(void);

void iansLockBH(void);

void iansUnlockBH(void);

void iansHotLock(BOOLEAN blockIntr, int *flags);

void iansHotUnlock(BOOLEAN blockIntr, int *flags);

void iansDevPut(device_t *ansDev); 

BOOLEAN iansIsKernelVersionGreaterThan2_4_0(void);

#endif
